<?php

namespace Drupal\standwithukraine\Service;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\standwithukraine\StandWithUkraineSettingsInterface;

/**
 * Provides a class that overrides message settings.
 *
 * It therefore uses StandWithUkraineNegotiatorInterface objects which are
 * passed in using the 'standwithukraine_negotiator' tag.
 */
class StandWithUkraineNegotiator implements StandWithUkraineNegotiatorInterface {

  /**
   * Holds an array of settings negotiator IDs, sorted by priority.
   *
   * @var string[]
   */
  protected $negotiators = [];

  /**
   * The class resolver.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * Constructs a new StandWithUkraineNegotiator.
   *
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver.
   * @param string[] $negotiators
   *   An array of negotiator IDs.
   */
  public function __construct(
    ClassResolverInterface $class_resolver,
    array $negotiators
  ) {
    $this->negotiators = $negotiators;
    $this->classResolver = $class_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public function applies(StandWithUkraineSettingsInterface $settings) {
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public function override(StandWithUkraineSettingsInterface $settings) {
    foreach ($this->negotiators as $negotiator_id) {
      $negotiator = $this->classResolver->getInstanceFromDefinition($negotiator_id);

      if ($negotiator->applies($settings)) {
        $negotiator->override($settings);
      }
    }
  }

}
