<?php

namespace Drupal\standwithukraine;

/**
 * Provides a class for message settings.
 */
class StandWithUkraineSettings implements StandWithUkraineSettingsInterface {

  /**
   * The text phrase.
   *
   * @var string
   */
  protected $text;

  /**
   * Display the message's text as a single line.
   *
   * @var bool
   */
  protected $single;

  /**
   * The font sizes list.
   *
   * @var array
   */
  protected $sizes;

  /**
   * The page side where a message should be displayed.
   *
   * @var string
   */
  protected $position;

  /**
   * The message offset.
   *
   * @var int
   */
  protected $offset;

  /**
   * Constructs a new StandWithUkraineSettings.
   *
   * @param bool $single
   *   Display the message's text as a single line.
   * @param string $position
   *   (optional) The page side where a message should be displayed. Defaults to
   *   StandWithUkraineSettingsInterface::POSITION_TOP.
   * @param int $offset
   *   (optional) The message offset. Defaults to 0.
   * @param string $text
   *   (optional) The text phrase. Defaults to
   *   StandWithUkraineSettingsInterface::TEXT.
   * @param array $sizes
   *   (optional) The font sizes list. Defaults to an empty array.
   */
  public function __construct(
    $single,
    $position = self::POSITION_TOP,
    $offset = 0,
    $text = self::TEXT,
    $sizes = []
  ) {
    $this->single = $single;
    $this->position = $position;
    $this->offset = $offset;
    $this->text = $text;
    $this->sizes = $sizes;
  }

  /**
   * {@inheritdoc}
   */
  public function getText() {
    return $this->text;
  }

  /**
   * {@inheritdoc}
   */
  public function setText($text) {
    $this->text = $text;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function isSingle() {
    return $this->single;
  }

  /**
   * {@inheritdoc}
   */
  public function setDouble() {
    $this->single = FALSE;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getSizes() {
    return $this->sizes;
  }

  /**
   * {@inheritdoc}
   */
  public function setSizes($first, $last) {
    $this->sizes = [
      'first' => $first,
      'last' => $last,
    ];

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getPosition() {
    return $this->position;
  }

  /**
   * {@inheritdoc}
   */
  public function setPosition($position) {
    $this->position = $position;

    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getOffset() {
    return $this->offset;
  }

  /**
   * {@inheritdoc}
   */
  public function setOffset($offset) {
    $this->offset = $offset;

    return $this;
  }

}
