<?php

namespace Drupal\standwithukraine;

/**
 * Defines an interface for class for message settings.
 */
interface StandWithUkraineSettingsInterface {

  /**
   * Sticky a message to the left side of the page.
   */
  const TEXT = 'Stand With' . PHP_EOL . 'Ukraine';

  /**
   * Sticky a message to the left side of the page.
   */
  const POSITION_LEFT = 'left';

  /**
   * Sticky a message to the top side of the page.
   */
  const POSITION_TOP = '';

  /**
   * Sticky a message to the right side of the page.
   */
  const POSITION_RIGHT = 'right';

  /**
   * Returns text phrase.
   *
   * @return string
   *   The text phrase.
   */
  public function getText();

  /**
   * Defines text phrase.
   *
   * @param string $text
   *   The text phrase.
   *
   * @return self
   *   The settings object.
   */
  public function setText($text);

  /**
   * Check if the message's text should be displayed in a single line.
   *
   * @return bool
   *   TRUE, if so.
   */
  public function isSingle();

  /**
   * Display message in view mode of two lines.
   *
   * @return self
   *   The settings object.
   */
  public function setDouble();

  /**
   * Returns a font size of each message line.
   *
   * @return array
   *   The font sizes list.
   */
  public function getSizes();

  /**
   * Defines which type of font size should be used for each message line.
   *
   * @param bool $first
   *   TRUE if the top message line should use a bigger font size.
   * @param bool $last
   *   TRUE if the bottom message line should use a bigger font size.
   *
   * @return self
   *   The settings object.
   */
  public function setSizes($first, $last);

  /**
   * Returns the page side where a message should be displayed.
   *
   * @return string
   *   The name of one of three available positions.
   */
  public function getPosition();

  /**
   * Defines the page side where a message should be displayed.
   *
   * @param string $position
   *   The position type.
   *
   * @return self
   *   The settings object.
   */
  public function setPosition($position);

  /**
   * Returns message offset.
   *
   * @return int
   *   The number of pixels.
   */
  public function getOffset();

  /**
   * Defines message offset.
   *
   * @param int $offset
   *   The number of pixels.
   *
   * @return self
   *   The settings object.
   */
  public function setOffset($offset);

}
